==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QAccessiblePlugin_shell.h <==
#ifndef QACCESSIBLEPLUGIN_SHELL_H
#define QACCESSIBLEPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessibleplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtJambi/RegistryAPI>


class QAccessiblePlugin_shell : public QAccessiblePlugin, public QtJambiShellInterface
{
public:
    QAccessiblePlugin_shell(QObject* parent0 = nullptr);
    ~QAccessiblePlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAccessibleInterface* create(const QString& key0, QObject* object1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessiblePlugin_access : public QAccessiblePlugin
{
    jobject __qt_create_cref_QString_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, QtJambiNativeID object1);
};

#endif // QACCESSIBLEPLUGIN_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QAccessiblePlugin_shell.h <==
#ifndef QACCESSIBLEPLUGIN_SHELL_H
#define QACCESSIBLEPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessibleplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qaccessible.h>
#include <QtJambi/RegistryAPI>


class QAccessiblePlugin_shell : public QAccessiblePlugin, public QtJambiShellInterface
{
public:
    QAccessiblePlugin_shell(QObject* parent0 = nullptr);
    ~QAccessiblePlugin_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QAccessiblePlugin_mshell;
    friend class QAccessiblePlugin_oshell;
};


class QAccessiblePlugin_mshell : public QAccessiblePlugin_shell
{
public:
    using QAccessiblePlugin_shell::QAccessiblePlugin_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAccessiblePlugin_oshell : public QAccessiblePlugin_mshell
{
public:
    using QAccessiblePlugin_mshell::QAccessiblePlugin_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAccessibleInterface* create(const QString& key0, QObject* object1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessiblePlugin_access : public QAccessiblePlugin
{
    jobject __qt_create_cref_QString_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, QtJambiNativeID object1);
};

#endif // QACCESSIBLEPLUGIN_SHELL_H
